REBOL [
	Title: "REBOL/View Desktop - Preferences"
	Version: 1.0.0
	Author: "Carl Sassenrath"
	Rights: "Copyright REBOL Technologies 1999-2003"
	Tabs: "Tabspace is 4. PLEASE KEEP IT THAT WAY."
	License: {
		This software is the property of REBOL Technologies and is
		licensed to you under the terms of the REBOL/View Desktop
		License (included in this distribution).
	}
]

prefs-file: none

;-- View Preferences Object --------------------------------------------------
;
;	This is the primary structure for holding View preferences.
;	This object is loaded when the user runs View and is saved to
;	disk when the user saves their preferences.
;
;	Because this object is always loaded by the View desktop on
;	startup, it must be loaded safely to avoid a possible virus.
;	The safe way to load the external preferences object is to use
;	the CONSTRUCT function and specify the default object below
;	as the /WITH refinement. [construct/with new-obj user-prefs]

user-prefs: context [
	name: "A Rebol"
	pass: none
	express: none
	server: "none"
	script: "none"
	proxy-user: none
	proxy-pass: none
	root: none
	poll-time: none
	connect-wait: none
	log: off
	debug: off
	window-size: none
	window-offset: none
	icon-offset: none
	keymap: none
	auto-connect: true
	always-close: true
	desktop: true
	skin: none
]

;-- Skin Defaults ------------------------------------------------------------
;
;	These are the default colors and effects that create the primary skin
;	for the desktop.

main-color: 175.155.120
base-color: 143.127.111		; background color
button-color: 44.80.132
over-color: button-color	; color when over text
bar-color: 180.180.250

dtw-skin: context [
	main-color: 160.180.160 ;180.200.180 ;140.170.140
	side-color: 100.140.100
	status-color: 80.80.100
	bottom-bar-color:
	top-bar-color: 100.120.100

	main-image: none 
	side-image: none 

	main-effect: [grid 150.170.150] ;170.190.170] ;120.140.120]
	side-effect: [gradient 0x1 200.220.200 100.120.100] ;180.210.180]

	base-text-color: black
	over-text-color: 140.20.20

	info-text-color: rebolor / 3
]

;-- Suffix Mappings ----------------------------------------------------------
;
;	This table maps file suffixes to REBOL words that are used to indicate
;	file types in the launch function. For example, a .txt file will convert
;	to a TEXT word, which will cause the Text Editor to launch.
;
;	This file map can also be loaded from disk as %desktop/filetypes.r.

suffix-map: [
	%.r %.rip rebol
	%.html %.htm html
	%.txt %.text text
	%.jpg %.png %.gif %.bmp image
	%.pdf pdf
	%.doc %.rtf %.dot ms-word
	%.xls %.csv ms-excel
]

load-file-types: has [data] [
	; Load the list of desktop filetypes:
	if error? try [data: load/all view-root/desktop/filetypes.r][exit]
	if data/1 = 'rebol [data: skip data 2]
	suffix-map: copy data
]

;-- Desktop Shortcuts --------------------------------------------------------
;
;	This table maps keyboard shortcuts to specific actions.
;	Future versions of ViewTop will allow this to be a preference file.

dtw-keymap: [
	#"^Q" [quit]
	#"^L" [do-local]
	#"^K" [halt-view]
	#"^E" [editor 'same]
	#"^H" [back-folder]
	#"^U" [view-prefs]
	#"^B" [halt]
	#"^R" [reload-folder]
	F5 [reload-folder]
]

;-- Load and Save Preference File --------------------------------------------

load-prefs: func [
	; Load user preferences from the prefs.r file.
	/local size
][
	if system/user/name [user-prefs/name: system/user/name]

	if all [
		prefs-file
		exists? prefs-file
		attempt [user-prefs: construct/with load prefs-file user-prefs]
	][
		size: system/view/screen-face/size
		if user-prefs/icon-offset [
			user-prefs/icon-offset: max 0x0 min user-prefs/icon-offset size - 100x74
		]

		if user-prefs/window-size [
			user-prefs/window-size: max 150x150 min user-prefs/window-size size
		]

		if user-prefs/window-offset [
			user-prefs/window-offset: max 0x0 min user-prefs/window-offset size - 
				any [user-prefs/window-size 320x320]
		]

		if user-prefs/proxy-user [
			system/schemes/default/proxy/user: user-prefs/proxy-user
		]

		if user-prefs/proxy-pass [
			system/schemes/default/proxy/pass: user-prefs/proxy-pass
		]

		if user-prefs/skin [dtw-skin: construct/with user-prefs/skin dtw-skin]
	]
	user-prefs
]

save-prefs: func [
	; Save user preferences object to the prefs.r file.
	/local str
][
	if not prefs-file [exit]
	str: reform [{REBOL [Title: "User Preferences" Date:} now {]^/}]
	foreach n next first user-prefs [
		repend str [n ": " mold get in user-prefs n newline]
	]
	write prefs-file str
]
